@@ -27,6 +27,6 @@ struct json_node {
 };
 
 int parsejson(const char *, size_t,
-              void (*cb)(struct json_node *, size_t, const char *, void *),
+              void (*cb)(struct json_node *, size_t, const char *, size_t, void *),
               void *);
 #endif
