@@ -9,10 +9,12 @@ size_t strlcat(char *, const char *, size_t);
 size_t strlcpy(char *, const char *, size_t);
 
 int decodeparam(char *buf, size_t bufsiz, const char *s);
+int durationstr(long secs, char *buf, size_t bufsiz);
 int friendlytime(time_t now, time_t t);
 char *getparam(const char *query, const char *s);
 void gophertext(FILE *fp, const char *s, size_t len);
 int hexdigit(int c);
+void printnumsep(const char *s);
 int uriencode(const char *s, char *buf, size_t bufsiz);
 int utf8pad(char *buf, size_t bufsiz, const char *s, size_t len, int pad);
 void xmlencode(const char *s);
